@@ -60,7 +60,8 @@ void KSample::Sample::fill(unsigned scale)
 {
   user = scale * 40; user /= 100;
   nice = scale * 25; user /= 100;
-  kernel = scale * 15; kernel /= 100;
+  kernel = scale * 10; kernel /= 100;
+  iowait = scale * 5; iowait /= 100;
   cpus = 1;
   buffers = scale * 20; buffers /= 100;
   used = scale * 30; used /= 100;
@@ -229,9 +230,10 @@ void KSample::readSample()
     if ( ( p = strstr(buffer, "Slab:") ) ) {
         unsigned long slabs;
         sscanf(p + 5, "%lu kB", &slabs);
-        sample.buffers += slabs;
+        sample.mkernel = slabs;
     }
 
+    /* read the data for the cpu stats */
     lseek(statFD, 0, 0);
     if ((l = read(statFD, buffer, sizeof(buffer)-1)) < 0)
         fatal(i18n("Unable to read the system usage file '%1'.\n"
@@ -239,8 +241,8 @@ void KSample::readSample()
 
     buffer[l] = '\0';
 
-    bool ok = (sscanf(buffer, "cpu %lu %lu %lu %lu", &sample.user,
-                      &sample.nice, &sample.kernel, &sample.idle) == 4);
+    bool ok = (sscanf(buffer, "cpu %lu %lu %lu %lu %lu", &sample.user,
+                      &sample.nice, &sample.kernel, &sample.idle, &sample.iowait) == 5);
 
     if (ok) {
         for (l = 0; l < MAX_CPU; l++) { // get individual stat for SMP machines
@@ -274,7 +276,8 @@ void KSample::readSample()
     sample.user = sysinfo.si_user;
     sample.nice = sysinfo.si_nice;
     sample.kernel = sysinfo.si_sys;
-    sample.idle = sysinfo.si_idle + sysinfo.wait;
+    sample.iowait = sysinfo.wait;
+    sample.idle = sysinfo.si_idle;
 
     struct tbl_vmstats vmstats;
     if (table(TBL_VMSTATS, 0, &vmstats, 1, sizeof(vmstats)) != 1)
@@ -306,9 +309,9 @@ void KSample::readSample()
         fatal(i18n("Unable to find any entries for CPU statistics "
                    "in the 'kstat' library. Are you running a non-standard "
                    "version of Solaris?\n"
-                   "Please contact the maintainer at mueller@kde.org who will try to sort this out."));
+                   "Please contact the maintainer via http://bugs.kde.org/ who will try to sort this out."));
 
-    sample.user = sample.nice = sample.kernel = sample.idle = 0;
+    sample.user = sample.nice = sample.kernel = sample.iowait = sample.idle = 0;
     sample.stotal = sample.sfree = 0;
 
     int cpus = 0;
@@ -321,12 +324,13 @@ void KSample::readSample()
             kstat_read(kc, ksp, &cstat) == -1) // and read into buffer
             fatal(i18n("Unable to read the CPU statistics entry "
                        "from the 'kstat' library. The diagnostics are '%1'.\n"
-                       "Please contact the maintainer at mueller@kde.org who will try to sort this out.").arg(strerror(errno)));
+                       "Please contact the maintainer via http://bugs.kde.org/ who will try to sort this out.").arg(strerror(errno)));
 
-        // fields are: idle user kernel iowait
+        // fields are: idle user kernel iowait (no nice info?)
         sample.user += cstat.cpu_sysinfo.cpu[1] / sample.cpus;
-        sample.nice += cstat.cpu_sysinfo.cpu[3] / sample.cpus;
+        sample.nice += 0;
         sample.kernel += cstat.cpu_sysinfo.cpu[2] / sample.cpus;
+        sample.iowait += cstat.cpu_sysinfo.cpu[3] / sample.cpus;
         sample.idle += cstat.cpu_sysinfo.cpu[0] / sample.cpus;
     }
 
@@ -334,7 +338,7 @@ void KSample::readSample()
         fatal(i18n("The number of CPUs appears to have changed at "
                    "very short notice, or the 'kstat' library returns "
                    "inconsistent results (%1 vs. %2 CPUs).\n"
-                   "Please contact the maintainer at mueller@kde.org who will try to sort this out.").arg(sample.cpus).arg(cpus));
+                   "Please contact the maintainer via http://bugs.kde.org/ who will try to sort this out.").arg(sample.cpus).arg(cpus));
 
     // availrmem = pages of core for user-proc ( == physmem - kernelmem)
     // freemem = no of free pages
@@ -346,7 +350,7 @@ void KSample::readSample()
         fatal(i18n("Unable to read the memory statistics entry "
                    "from the 'kstat' library. The diagnostics are '%1'\n"
                    "You might want to contact the maintainer at "
-                   "mueller@kde.org who will try to sort this out.").arg(strerror(errno)));
+                   "http://bugs.kde.org/ who will try to sort this out.").arg(strerror(errno)));
 
     int i;
     unsigned long physmem = 0, freemem = 0, availrmem = 0;
@@ -374,7 +378,7 @@ void KSample::readSample()
     if ((swapentries = swapctl(SC_GETNSWP, 0)) == -1)
         fatal(i18n("Unable to determine the number of "
                    "swap spaces. The diagnostics are '%1'.\n"
-                   "Please contact the maintainer at mueller@kde.org who will try to sort this out.").arg(strerror(errno)));
+                   "Please contact the maintainer at http://bugs.kde.org/ who will try to sort this out.").arg(strerror(errno)));
 
     if (swapentries != 0) {
                                 // 2* to get some space for padding??
@@ -384,7 +388,7 @@ void KSample::readSample()
             fatal(i18n("KTimeMon ran out of memory while "
                        "trying to determine the swap usage.\n"
                        "Attempted to allocate %1 bytes of memory (2 * %2 + %3 * %4).\n"
-                       "Please contact the maintainer at mueller@kde.org who will try to sort this out.")
+                       "Please contact the maintainer at http://bugs.kde.org/ who will try to sort this out.")
                   .arg(2 * sizeof(int) + swapentries * sizeof(struct swapent))
                   .arg(sizeof(int)).arg(swapentries).arg(sizeof(struct swapent)));
 
@@ -395,7 +399,7 @@ void KSample::readSample()
         if ((swapentries = swapctl(SC_LIST, stbl)) == -1)
             fatal(i18n("Unable to determine the swap usage.\n"
                        "The diagnostics are '%1'.\n"
-                       "Please contact the maintainer at mueller@kde.org who will try to sort this out.").arg(strerror(errno)));
+                       "Please contact the maintainer at http://bugs.kde.org/ who will try to sort this out.").arg(strerror(errno)));
 
 
         if (!warned && swapentries != stbl->swt_n) {
@@ -403,7 +407,7 @@ void KSample::readSample()
             nonfatal(i18n("Information was requested for "
                           "%1 swap spaces, but only %2 swap entries were returned.\n"
                           "KTimeMon will attempt to continue.\n"
-                          "Please contact the maintainer at mueller@kde.org who will try to sort this out.").arg(stbl->swt_n).arg(swapentries));
+                          "Please contact the maintainer at http://bugs.kde.org/ who will try to sort this out.").arg(stbl->swt_n).arg(swapentries));
         }
 
         for (i = 0; i < swapentries; i++) {
@@ -419,7 +423,8 @@ void KSample::readSample()
     sample.stotal = sample.sfree = 0;
 #endif
 
-    sample.cputotal = sample.user + sample.nice + sample.kernel + sample.idle;
+    sample.cputotal = 
+      sample.user + sample.nice + sample.kernel + sample.iowait + sample.idle;
     sample.used = sample.mtotal - sample.free - sample.buffers - sample.cached;
     sample.sused = sample.stotal - sample.sfree;
 }
@@ -451,6 +456,7 @@ KSample::Sample KSample::getRawSample()
     diff.user -= oldSample.user;
     diff.nice -= oldSample.nice;
     diff.kernel -= oldSample.kernel;
+    diff.iowait -= oldSample.iowait;
 
     for (int i = 0; i < diff.cpus; i++) {
         diff.smptotal[i] -= oldSample.smptotal[i];
@@ -483,6 +489,7 @@ KSample::Sample KSample::getSample(unsigned scale)
     s.user = doScale(s.user, scale, s.cputotal);
     s.nice = doScale(s.nice, scale, s.cputotal);
     s.kernel = doScale(s.kernel, scale, s.cputotal);
+    s.iowait = doScale(s.iowait, scale, s.cputotal);
 
     for (int i = 0; i < s.cpus; i++)
         s.smpbusy[i] = doScale(s.smpbusy[i], scale, s.smptotal[i]);
@@ -490,6 +497,7 @@ KSample::Sample KSample::getSample(unsigned scale)
     s.cached = doScale(s.cached, scale, s.mtotal);
     s.buffers = doScale(s.buffers, scale, s.mtotal);
     s.used = doScale(s.used, scale, s.mtotal);
+    s.mkernel = doScale(s.mkernel, scale, s.mtotal);
     makeMBytes(s.mtotal);
 
     s.sused = doScale(s.sused, scale, s.stotal);
