@@ -1,10 +1,9 @@
 /***************************************************************************
-                          jukInterface.h
-            this is the abstract class to access JuK from
+                           Interface to access JuK
                              -------------------
-    begin                : Mon Jan 15 21:09:00 MEZ 2001
+    begin                : Mon Jan 15 21:09:00 CEST 2001
     copyright            : (C) 2001-2002 by Stefan Gehn
-    email                : sgehn@gmx.net
+    email                : metz {AT} gehn {DOT} net
  ***************************************************************************/
 
 /***************************************************************************
@@ -26,6 +25,8 @@
 
 #include <qtimer.h>
 
+class QProcess;
+
 class JuKInterface : public PlayerInterface
 {
 	Q_OBJECT
@@ -53,9 +54,11 @@ class JuKInterface : public PlayerInterface
 		void myInit();
 		void appRegistered ( const QCString &appId );
 		void appRemoved ( const QCString &appId );
+		void jukIsReady();
 
 	private:
 		QTimer *mJuKTimer;
+		QProcess *mProc;
 		int mTimerValue;
 		QCString mAppId;
 
