@@ -1,9 +1,9 @@
 /***************************************************************************
-                          mediacontrol.h  -  description
+                         main file of mediacontrol applet
                              -------------------
     begin                : Tue Apr 25 11:53:11 CEST 2000
-    copyright            : (C) 2000 by Stefan Gehn
-    email                : sgehn@gmx.net
+    copyright            : (C) 2000-2005 by Stefan Gehn
+    email                : metz {AT} gehn {DOT} net
  ***************************************************************************/
 
 /***************************************************************************
@@ -46,6 +46,7 @@ class KPopupMenu;
 class KInstance;
 class MediaControlConfig;
 class KAboutData;
+class MediaControlToolTip;
 
 // =============================================================================
 
