@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -114,10 +114,10 @@ void KonqFeedIcon::contextMenu()
     m_menu = new KPopupMenu(m_part->widget());
     if(m_feedList.count() == 1) {
         m_menu->insertTitle(m_feedList.first().title());
-        m_menu->insertItem(SmallIcon("bookmark_add"), i18n("Add Feed to aKregator"), this, SLOT(addFeeds()) );
+        m_menu->insertItem(SmallIcon("bookmark_add"), i18n("Add Feed to Akregator"), this, SLOT(addFeeds()) );
     }
     else {
-        m_menu->insertTitle(i18n("Add Feeds to aKregator"));
+        m_menu->insertTitle(i18n("Add Feeds to Akregator"));
         connect(m_menu, SIGNAL(activated(int)), this, SLOT(addFeed(int)));
         int id = 0;
         for(FeedDetectorEntryList::Iterator it = m_feedList.begin(); it != m_feedList.end(); ++it) {
@@ -126,7 +126,7 @@ void KonqFeedIcon::contextMenu()
         }
         //disconnect(m_menu, SIGNAL(activated(int)), this, SLOT(addFeed(int)));
         m_menu->insertSeparator();
-        m_menu->insertItem(SmallIcon("bookmark_add"), i18n("Add All Found Feeds to aKregator"), this, SLOT(addFeeds()), 0, 50000 );
+        m_menu->insertItem(SmallIcon("bookmark_add"), i18n("Add All Found Feeds to Akregator"), this, SLOT(addFeeds()), 0, 50000 );
     }
     m_menu->popup(QCursor::pos());
 }
@@ -150,7 +150,7 @@ void KonqFeedIcon::addFeedIcon()
     m_feedIcon->setPixmap(QPixmap(locate("data", "akregator/pics/rss.png")));
 
     QToolTip::remove(m_feedIcon);
-    QToolTip::add(m_feedIcon, i18n("This site has a feed", "This site has %n feeds", m_feedList.count()));
+    QToolTip::add(m_feedIcon, i18n("Monitor this site for updates (using news feed)"));
 
     m_statusBarEx->addStatusBarItem(m_feedIcon, 0, true);
 
