@@ -43,6 +43,7 @@
 #include <qwidgetstack.h>
 
 #include <dom/dom_core.h>
+#include <dom/html_base.h>
 
 #include <kaction.h>
 #include <kdebug.h>
@@ -74,7 +75,7 @@ DOMTreeView::DOMTreeView(QWidget *parent, const char* name, bool /*allowSaving*/
   m_listView->setFont( font );
   m_listView->setSorting(-1);
   m_rootListView = m_listView;
-  
+
   m_pureCheckBox->setChecked(m_bPure);
   connect(m_pureCheckBox, SIGNAL(toggled(bool)), this, SLOT(slotPureToggled(bool)));
 
@@ -85,26 +86,26 @@ DOMTreeView::DOMTreeView(QWidget *parent, const char* name, bool /*allowSaving*/
   m_highlightHTMLCheckBox->setChecked(m_bHighlightHTML);
   connect(m_highlightHTMLCheckBox, SIGNAL(toggled(bool)), this,
          SLOT(slotHighlightHTMLToggled(bool)));
-  
+
   connect(m_listView, SIGNAL(clicked(QListViewItem *)), this,
 	  SLOT(slotItemClicked(QListViewItem *)));
   connect(m_listView, SIGNAL(contextMenuRequested(QListViewItem *, const QPoint &, int)),
   	SLOT(showDOMTreeContextMenu(QListViewItem *, const QPoint &, int)));
   connect(m_listView, SIGNAL(moved(QPtrList<QListViewItem> &, QPtrList<QListViewItem> &, QPtrList<QListViewItem> &)),
         SLOT(slotMovedItems(QPtrList<QListViewItem> &, QPtrList<QListViewItem> &, QPtrList<QListViewItem> &)));
-	
+
   // set up message line
   messageLinePane->hide();
   connect(messageHideBtn, SIGNAL(clicked()), SLOT(hideMessageLine()));
   connect(messageListBtn, SIGNAL(clicked()), mainWindow(), SLOT(showMessageLog()));
 
   installEventFilter(m_listView);
-  
+
   ManipulationCommand::connect(SIGNAL(nodeChanged(const DOM::Node &)), this, SLOT(slotRefreshNode(const DOM::Node &)));
   ManipulationCommand::connect(SIGNAL(structureChanged()), this, SLOT(refresh()));
-  
+
   initDOMNodeInfo();
-  
+
   installEventFilter(this);
 }
 
@@ -122,7 +123,7 @@ void DOMTreeView::setHtmlPart(KHTMLPart *_part)
   if (oldPart) {
     // nothing here yet
   }
-  
+
   parentWidget()->setCaption( part ? i18n( "DOM Tree for %1" ).arg(part->url().prettyURL()) : i18n("DOM Tree") );
 
   QTimer::singleShot(0, this, SLOT(slotSetHtmlPartDelayed()));
@@ -131,43 +132,43 @@ void DOMTreeView::setHtmlPart(KHTMLPart *_part)
 DOMTreeWindow *DOMTreeView::mainWindow() const
 {
   return static_cast<DOMTreeWindow *>(parentWidget());
-}   
+}
 
 bool DOMTreeView::eventFilter(QObject *o, QEvent *e)
 {
   if (e->type() == QEvent::AccelOverride) {
     QKeyEvent *ke = static_cast<QKeyEvent *>(e);
     kdDebug(90180) << " acceloverride " << ke->key() << " o " << o->name() << endl;
-    
+
     if (o == m_listView) {	// DOM tree
       KKey ks = mainWindow()->deleteNodeAction()->shortcut().seq(0).key(0);
-      if (ke->key() == ks.keyCodeQt());
+      if (ke->key() == ks.keyCodeQt())
         return true;
-      
+
     } else if (o == nodeAttributes) {
       KKey ks = mainWindow()->deleteAttributeAction()->shortcut().seq(0).key(0);
-      if (ke->key() == ks.keyCodeQt());
+      if (ke->key() == ks.keyCodeQt())
         return true;
-    
+
     }
-    
+
   } else if (e->type() == QEvent::FocusIn) {
-    
+
     kdDebug(90180) << " focusin o " << o->name() << endl;
     if (o != this) {
       focused_child = o;
     }
-  
+
   } else if (e->type() == QEvent::FocusOut) {
-  
+
     kdDebug(90180) << " focusout o " << o->name() << endl;
     if (o != this) {
       focused_child = 0;
     }
-  
+
   }
 
-  return false;  
+  return false;
 }
 
 void DOMTreeView::activateNode(const DOM::Node &node)
@@ -178,7 +179,7 @@ void DOMTreeView::activateNode(const DOM::Node &node)
 
 void DOMTreeView::slotShowNode(const DOM::Node &pNode)
 {
-  
+
   if (QListViewItem *item = m_itemdict[pNode.handle()]) {
     m_listView->setCurrentItem(item);
     m_listView->ensureItemVisible(item);
@@ -235,6 +236,10 @@ void DOMTreeView::showRecursive(const DOM::Node &pNode, const DOM::Node &node, u
   }
 
   DOM::Node child = node.lastChild();
+  if (child.isNull()) {
+    DOM::HTMLFrameElement frame = node;
+    if (!frame.isNull()) child = frame.contentDocument().documentElement();
+  }
   while(!child.isNull()) {
     showRecursive(node, child, depth + 1);
     child = child.previousSibling();
@@ -259,7 +264,7 @@ void DOMTreeView::showRecursive(const DOM::Node &pNode, const DOM::Node &node, u
 void DOMTreeView::addElement ( const DOM::Node &node,  DOMListViewItem *cur_item, bool isLast)
 {
   cur_item->setClosing(isLast);
-  
+
   const QString nodeName(node.nodeName().string());
   QString text;
   const DOM::Element element = node;
@@ -420,7 +425,7 @@ void DOMTreeView::slotItemClicked(QListViewItem *cur_item)
 {
   DOMListViewItem *cur = static_cast<DOMListViewItem *>(cur_item);
   if (!cur) return;
-  
+
   DOM::Node handle = cur->node();
   if (!handle.isNull()) {
     part->setActiveNode(handle);
@@ -440,14 +445,14 @@ void DOMTreeView::slotRefreshNode(const DOM::Node &pNode)
 {
   DOMListViewItem *cur = static_cast<DOMListViewItem *>(m_itemdict[pNode.handle()]);
   if (!cur) return;
-  
+
   addElement(pNode, cur, false);
 }
 
 void DOMTreeView::slotPrepareMove()
 {
   DOMListViewItem *item = static_cast<DOMListViewItem *>(m_listView->currentItem());
-  
+
   if (!item)
     current_node = DOM::Node();
   else
@@ -458,7 +463,7 @@ void DOMTreeView::slotMovedItems(QPtrList<QListViewItem> &items, QPtrList<QListV
 {
   MultiCommand *cmd = new MultiCommand(i18n("Move Nodes"));
   _refreshed = false;
-    
+
   QPtrList<QListViewItem>::Iterator it = items.begin();
   QPtrList<QListViewItem>::Iterator anit = afterNow.begin();
   for (; it != items.end(); ++it, ++anit) {
@@ -466,19 +471,19 @@ void DOMTreeView::slotMovedItems(QPtrList<QListViewItem> &items, QPtrList<QListV
     DOMListViewItem *anitem = static_cast<DOMListViewItem *>(*anit);
     DOM::Node parent = static_cast<DOMListViewItem *>(item->parent())->node();
     Q_ASSERT(!parent.isNull());
-    
+
 // kdDebug(90180) << " afternow " << anitem << " node " << (anitem ? anitem->node().nodeName().string() : QString()) << "=" << (anitem ? anitem->node().nodeValue().string() : QString()) << endl;
-   
+
     cmd->addCommand(new MoveNodeCommand(item->node(), parent,
       anitem ? anitem->node().nextSibling() : parent.firstChild())
     );
   }
-  
+
   mainWindow()->executeAndAddCommand(cmd);
-  
+
   // refresh *anyways*, otherwise consistency is disturbed
   if (!_refreshed) refresh();
-  
+
   slotShowNode(current_node);
 }
 
@@ -526,7 +531,7 @@ void DOMTreeView::slotSaveClicked()
     if (file.exists()) {
       const QString title = i18n( "File Exists" );
       const QString text = i18n( "Do you really want to overwrite: \n%1?" ).arg(url.url());
-      if (KMessageBox::Yes != KMessageBox::warningYesNoCancel(this, text, title ) ) {
+      if (KMessageBox::Continue != KMessageBox::warningContinueCancel(this, text, title, i18n("Overwrite") ) ) {
 	return;
       }
     }
@@ -643,10 +648,10 @@ void DOMTreeView::refresh()
   if (!part) return;
   scroll_ofs_x = m_listView->contentsX();
   scroll_ofs_y = m_listView->contentsY();
-  
+
   m_listView->setUpdatesEnabled(false);
   slotShowTree(part->document());
-  
+
   QTimer::singleShot(0, this, SLOT(slotRestoreScrollOffset()));
   _refreshed = true;
 }
@@ -681,13 +686,13 @@ void DOMTreeView::adjustDepth()
   DOMListViewItem *cur_node_item = m_itemdict[infoNode.handle()];
   if (!cur_node_item)
     cur_node_item = static_cast<DOMListViewItem *>(m_listView->currentItem());
-  
+
   adjustDepthRecursively(m_rootListView->firstChild(), 0);
-  
+
   // make current item visible again if possible
   if (cur_node_item)
     m_listView->ensureVisible(0, cur_node_item->itemPos());
-  
+
 }
 
 void DOMTreeView::adjustDepthRecursively(QListViewItem *cur_item,  uint currDepth)
@@ -767,7 +772,7 @@ void DOMTreeView::deleteNodes()
 
     // don't regard node more than once
     if (item->node() == last) continue;
-        
+
     // check for selected parent
     bool has_selected_parent = false;
     for (QListViewItem *p = item->parent(); p; p = p->parent()) {
@@ -863,23 +868,23 @@ void DOMTreeView::slotAddElementDlg()
   QString qname;
   QString namespc;
   SignalReceiver addBefore;
-    
+
   {
     ElementEditDialog dlg(this, "ElementEditDialog", true);
     connect(dlg.insBeforeBtn, SIGNAL(clicked()), &addBefore, SLOT(slot()));
-    
+
     // ### activate when namespaces are supported
     dlg.elemNamespace->setEnabled(false);
-  
+
     if (dlg.exec() != QDialog::Accepted) return;
-    
+
     qname = dlg.elemName->text();
     namespc = dlg.elemNamespace->currentText();
   }
 
   DOM::Node curNode = item->node();
 
-  try {  
+  try {
     DOM::Node parent = addBefore() ? curNode.parentNode() : curNode;
     DOM::Node after = addBefore() ? curNode : 0;
 
@@ -888,9 +893,9 @@ void DOMTreeView::slotAddElementDlg()
 
     ManipulationCommand *cmd = new InsertNodeCommand(newNode, parent, after);
     mainWindow()->executeAndAddCommand(cmd);
-  
+
     if (cmd->isValid()) activateNode(newNode);
-    
+
   } catch (DOM::DOMException &ex) {
     mainWindow()->addMessage(ex.code, domErrorMessage(ex.code));
   }
@@ -903,19 +908,19 @@ void DOMTreeView::slotAddTextDlg()
 
   QString text;
   SignalReceiver addBefore;
-    
+
   {
     TextEditDialog dlg(this, "TextEditDialog", true);
     connect(dlg.insBeforeBtn, SIGNAL(clicked()), &addBefore, SLOT(slot()));
-    
+
     if (dlg.exec() != QDialog::Accepted) return;
-    
+
     text = dlg.textPane->text();
   }
 
   DOM::Node curNode = item->node();
 
-  try {  
+  try {
     DOM::Node parent = addBefore() ? curNode.parentNode() : curNode;
     DOM::Node after = addBefore() ? curNode : 0;
 
@@ -923,9 +928,9 @@ void DOMTreeView::slotAddTextDlg()
 
     ManipulationCommand *cmd = new InsertNodeCommand(newNode, parent, after);
     mainWindow()->executeAndAddCommand(cmd);
-  
+
     if (cmd->isValid()) activateNode(newNode);
-    
+
   } catch (DOM::DOMException &ex) {
     mainWindow()->addMessage(ex.code, domErrorMessage(ex.code));
   }
@@ -964,7 +969,7 @@ public:
   virtual int compare(QListViewItem *item, int column, bool ascend) const
   {
     return _new ? 1 : super::compare(item, column, ascend);
-  } 
+  }
 
 protected:
   virtual void paintCell( QPainter *p, const QColorGroup &cg,
@@ -972,14 +977,14 @@ protected:
   {
     bool updates_enabled = listView()->isUpdatesEnabled();
     listView()->setUpdatesEnabled(false);
-    
+
     QColor c = cg.text();
     bool text_changed = false;
     QString oldText;
-    
+
     if (_new) {
       c = QApplication::palette().color( QPalette::Disabled, QColorGroup::Text );
-      
+
       if (!clickToAdd) clickToAdd = new QString(i18n("<Click to add>"));
       oldText = text(column);
       text_changed = true;
@@ -989,7 +994,7 @@ protected:
     QColorGroup _cg( cg );
     _cg.setColor( QColorGroup::Text, c );
     super::paintCell( p, _cg, column, width, alignment );
-    
+
     if (text_changed) setText(column, oldText);
     listView()->setUpdatesEnabled(updates_enabled);
   }
@@ -1014,9 +1019,9 @@ void DOMTreeView::initDOMNodeInfo()
 
   nodeAttributes->setRenameable(0, true);
   nodeAttributes->setRenameable(1, true);
-  
+
   nodeInfoStack->raiseWidget(EmptyPanel);
-  
+
   installEventFilter(nodeAttributes);
 }
 
@@ -1038,7 +1043,7 @@ void DOMTreeView::initializeOptionsFromNode(const DOM::Node &node)
   nodeType->setText(QString::number(node.nodeType()));
   nodeNamespace->setText(node.namespaceURI().string());
 //   nodeValue->setText(node.value().string());
-  
+
   DOM::Element element = node;
   if (!element.isNull()) {
     initializeOptionsFromElement(element);
@@ -1100,7 +1105,7 @@ void DOMTreeView::slotItemRenamed(QListViewItem *lvi, const QString &str, int co
 
   DOM::Element element = infoNode;
   if (element.isNull()) return; // Should never happen
-  
+
   switch (col) {
     case 0: {
       ManipulationCommand *cmd;
@@ -1110,13 +1115,13 @@ void DOMTreeView::slotItemRenamed(QListViewItem *lvi, const QString &str, int co
 	item->setNew(false);
       } else
         cmd = new RenameAttributeCommand(element, item->text(0), str);
-      
+
       mainWindow()->executeAndAddCommand(cmd);
       break;
     }
     case 1: {
       if (item->isNew()) { lvi->setText(1, QString()); break; }
-      
+
       ChangeAttributeValueCommand *cmd = new ChangeAttributeValueCommand(
       			  element, item->text(0), str);
       mainWindow()->executeAndAddCommand(cmd);
@@ -1132,12 +1137,12 @@ void DOMTreeView::slotEditAttribute(QListViewItem *lvi, const QPoint &, int col)
   QString attrName = lvi->text(0);
   QString attrValue = lvi->text(1);
   int res = 0;
-  
+
   {
     AttributeEditDialog dlg(this, "AttributeEditDialog", true);
     dlg.attrName->setText(attrName);
     dlg.attrValue->setText(attrValue);
-  
+
     if (col == 0) {
       dlg.attrName->setFocus();
       dlg.attrName->selectAll();
@@ -1145,22 +1150,22 @@ void DOMTreeView::slotEditAttribute(QListViewItem *lvi, const QPoint &, int col)
       dlg.attrValue->setFocus();
       dlg.attrValue->selectAll();
     }
-  
+
     res = dlg.exec();
-    
+
     attrName = dlg.attrName->text();
     attrValue = dlg.attrValue->text();
   }
 
 //   kdDebug(90180) << "name=" << attrName << " value=" << attrValue << endl;
-  
+
   if (res == QDialog::Accepted) do {
     if (attrName.isEmpty()) break;
 
     if (lvi->text(0) != attrName) {
       // hack: set value to assign attribute/value pair in one go
       lvi->setText(1, attrValue);
-    
+
       slotItemRenamed(lvi, attrName, 0);
       // Reget, item may have been changed
       lvi = nodeAttributes->findItem(attrName, 0);
@@ -1168,7 +1173,7 @@ void DOMTreeView::slotEditAttribute(QListViewItem *lvi, const QPoint &, int col)
 
     if (lvi && lvi->text(1) != attrValue)
       slotItemRenamed(lvi, attrValue, 1);
-      
+
   } while(false) /*end if*/;
 }
 
@@ -1176,9 +1181,9 @@ void DOMTreeView::slotEditAttribute(QListViewItem *lvi, const QPoint &, int col)
 void DOMTreeView::slotApplyContent()
 {
   DOM::CharacterData cdata = infoNode;
-  
+
   if (cdata.isNull()) return;
-  
+
   ManipulationCommand *cmd = new ChangeCDataCommand(cdata, contentEditor->text());
   mainWindow()->executeAndAddCommand(cmd);
 }
