@@ -48,7 +48,7 @@ Boston, MA 02110-1301, USA.
 typedef KGenericFactory<KImGalleryPlugin> KImGalleryPluginFactory;
 K_EXPORT_COMPONENT_FACTORY( libkimgallery, KImGalleryPluginFactory( "imgalleryplugin" ) )
 
-    KImGalleryPlugin::KImGalleryPlugin( QObject* parent, const char* name, const QStringList & )
+KImGalleryPlugin::KImGalleryPlugin( QObject* parent, const char* name, const QStringList & )
         : KParts::Plugin( parent, name ), m_commentMap(0)
 {
     new KAction( i18n( "&Create Image Gallery..." ), "imagegallery", CTRL+Key_I, this,
@@ -228,7 +228,7 @@ void KImGalleryPlugin::createBody(QTextStream& stream, const QString& sourceDirN
             }
 
             if (m_useCommentFile) {
-                QString imgComment = (*m_commentMap)[imgName].local8Bit();
+                QString imgComment = (*m_commentMap)[imgName];
                 stream << "<div>" << QStyleSheet::escape(imgComment) << "</div>" << endl;
             }
             stream << "</td>" << endl;
@@ -410,7 +410,7 @@ void KImGalleryPlugin::loadCommentFile()
         }
         CommentMap::Iterator it;
         for( it = m_commentMap->begin(); it != m_commentMap->end(); ++it ) {
-            kdDebug(90170) << "picName: " << it.key().local8Bit() << ", picComment: " << it.data().local8Bit() << endl;
+            kdDebug(90170) << "picName: " << it.key() << ", picComment: " << it.data() << endl;
         }
         file.close();
         kdDebug(90170) << "File closed." << endl;
