@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #include <kiconloader.h>
@@ -106,7 +106,7 @@ KMetaMenu::KMetaMenu( QWidget *parent, const KURL &url,
         m_contacts = new KIMContactMenu( parent, imProxy );
         int item = insertItem( SmallIconSet( "personal" ), i18n( "C&ontact" ), m_contacts );
         connect ( m_contacts, SIGNAL( contactChosen( const QString &) ), SIGNAL( contactChosen( const QString & ) ) );
-        if ( !imProxy->initialize() && imProxy->imAppsAvailable() )
+        if ( !imProxy->initialize() || imProxy->fileTransferContacts().isEmpty() )
           setItemEnabled( item, false );
     }
 
