@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef SEARCHBAR_PLUGIN
@@ -98,7 +98,7 @@ class SearchBarCombo : public KHistoryCombo
  * provider it will use.
  *
  * @author Arend van Beelen jr. <arend@auton.nl>
- * @version $Id: searchbar.h 339549 2004-08-21 14:18:50Z arendjr $
+ * @version $Id: searchbar.h 465369 2005-09-29 14:33:08Z mueller $
  */
 class SearchBarPlugin : public KParts::Plugin
 {
@@ -112,6 +112,9 @@ class SearchBarPlugin : public KParts::Plugin
 		                const QStringList &);
 		virtual ~SearchBarPlugin();
 
+	protected:
+		bool eventFilter(QObject *o, QEvent *e);
+
 	private slots:
 		/**
 		 * Starts a search by putting the query URL from the selected
@@ -130,9 +133,9 @@ class SearchBarPlugin : public KParts::Plugin
 		void showSelectionMenu();
 
 		void useFindInThisPage();
-		void useSearchProvider();
-		void selectSearchEngine();
-		void searchEngineSelected(KProcess *process);
+		void useSearchProvider(int);
+		void selectSearchEngines();
+		void searchEnginesSelected(KProcess *process);
 		void configurationChanged();
 
 		/**
@@ -144,7 +147,12 @@ class SearchBarPlugin : public KParts::Plugin
 		 * Show or hide the combo box
 		 */
 		void updateComboVisibility();
+
+		void focusSearchbar();
 	private:
+		void nextSearchEntry();
+		void previousSearchEntry();
+
 		QGuardedPtr<KHTMLPart> m_part;
 		SearchBarCombo        *m_searchCombo;
                 KWidgetAction         *m_searchComboAction;
@@ -153,6 +161,8 @@ class SearchBarPlugin : public KParts::Plugin
 		SearchModes            m_searchMode;
 		QString                m_providerName;
 		bool                   m_urlEnterLock;
+		QString                m_currentEngine;
+		QStringList            m_searchEngines;
 };
 
 #endif // SEARCHBAR_PLUGIN
