@@ -54,6 +54,31 @@ private slots:
 	void slicesModified();
 };
 
+
+class SchemaListAction : public KActionMenu
+{
+Q_OBJECT
+	QMap<int, QString> mIndexToSchemas;
+	Tree *mTree;
+
+public:
+	SchemaListAction(
+			const QString &text,
+			QObject *reciever, const char *slot,
+			QObject *parent, const char *name
+		);
+
+	void setTree(Tree *tree) { mTree = tree; }
+
+signals:
+	void activated(const QString &);
+
+private slots:
+	void hit(int index);
+	void prepare();
+};
+
+
 class ObliquePropertiesDialog : public KPropertiesDialog
 {
 Q_OBJECT
