@@ -4,8 +4,8 @@
 #ifndef TYLER_H
 #define TYLER_H
 
-#include <conversion.h>
-#include <plugin.h>
+#include <noatun/conversion.h>
+#include <noatun/plugin.h>
 #include <kprocess.h>
 #include <qwidget.h>
 
